.. _changelog:

*********
Changelog
*********

For better reproducibility, specific versions of ObsPy can be cited using the
`DOIs assigned to releases of ObsPy
<https://zenodo.org/search?ln=en&p=obspy&action_search=>`_ or
`ObsPy in general can be cited using a concept DOI
<https://doi.org/10.5281/zenodo.3674645>`_
(see `Zenodo FAQ <http://help.zenodo.org/#versioning>`_).

.. mdinclude:: ../../../CHANGELOG.txt
